@@ -48,23 +48,23 @@ void srl_decoder_destructor_hook(pTHX_ void *p);
 #define SRL_BASE_ERROR_FORMAT "Sereal: Error in %s line %u: "
 #define SRL_BASE_ERROR_ARGS __FILE__, __LINE__
 
-#define ERROR(msg)                          croak(SRL_BASE_ERROR_FORMAT "%s", SRL_BASE_ERROR_ARGS, (msg))
-#define ERRORf1(fmt,var)                    croak(SRL_BASE_ERROR_FORMAT fmt, SRL_BASE_ERROR_ARGS, (var))
-#define ERRORf2(fmt,var1,var2)              croak(SRL_BASE_ERROR_FORMAT fmt, SRL_BASE_ERROR_ARGS, (var1),(var2))
-#define ERRORf3(fmt,var1,var2,var3)         croak(SRL_BASE_ERROR_FORMAT fmt, SRL_BASE_ERROR_ARGS, (var1),(var2),(var3))
-#define ERRORf4(fmt,var1,var2,var3,var4)    croak(SRL_BASE_ERROR_FORMAT fmt, SRL_BASE_ERROR_ARGS, (var1),(var2),(var3),(var4))
-#define ERROR_UNIMPLEMENTED(dec,tag,str) \
-    ERRORf3("Tag %u %s is unimplemented at ofs: %d", (tag), (str), BUF_POS_OFS(dec))
-#define ERROR_UNTERMINATED(dec,tag,str) \
-    ERRORf4("Tag SRL_HDR_%s %s was not terminated properly at ofs %lu with %lu to go", \
+#define SRL_ERROR(msg)                          croak(SRL_BASE_ERROR_FORMAT "%s", SRL_BASE_ERROR_ARGS, (msg))
+#define SRL_ERRORf1(fmt,var)                    croak(SRL_BASE_ERROR_FORMAT fmt, SRL_BASE_ERROR_ARGS, (var))
+#define SRL_ERRORf2(fmt,var1,var2)              croak(SRL_BASE_ERROR_FORMAT fmt, SRL_BASE_ERROR_ARGS, (var1),(var2))
+#define SRL_ERRORf3(fmt,var1,var2,var3)         croak(SRL_BASE_ERROR_FORMAT fmt, SRL_BASE_ERROR_ARGS, (var1),(var2),(var3))
+#define SRL_ERRORf4(fmt,var1,var2,var3,var4)    croak(SRL_BASE_ERROR_FORMAT fmt, SRL_BASE_ERROR_ARGS, (var1),(var2),(var3),(var4))
+#define SRL_ERROR_UNIMPLEMENTED(dec,tag,str) \
+    SRL_ERRORf3("Tag %u %s is unimplemented at ofs: %d", (tag), (str), BUF_POS_OFS(dec))
+#define SRL_ERROR_UNTERMINATED(dec,tag,str) \
+    SRL_ERRORf4("Tag SRL_HDR_%s %s was not terminated properly at ofs %lu with %lu to go", \
             tag_name[(tag) & 127], (str), (dec)->pos - (dec)->buf_start, (dec)->buf_end - (dec)->pos)
-#define ERROR_BAD_COPY(dec, tag) \
-    ERRORf1("While processing tag SRL_HDR_%s encountered a bad COPY tag", tag_name[(tag) & 127])
-#define ERROR_UNEXPECTED(dec, tag, msg) \
-    ERRORf2("Unexpected tag %s while expecting %s", tag_name[(tag || *(dec)->pos) & 127], msg)
-#define ERROR_REFUSE_OBJECT() \
-    ERROR("Encountered object in input, but the 'refuse_objects' option is in effect");
-#define ERROR_PANIC(dec, msg) ERRORf1("Panic: %s", msg);
+#define SRL_ERROR_BAD_COPY(dec, tag) \
+    SRL_ERRORf1("While processing tag SRL_HDR_%s encountered a bad COPY tag", tag_name[(tag) & 127])
+#define SRL_ERROR_UNEXPECTED(dec, tag, msg) \
+    SRL_ERRORf2("Unexpected tag %s while expecting %s", tag_name[(tag || *(dec)->pos) & 127], msg)
+#define SRL_ERROR_REFUSE_OBJECT() \
+    SRL_ERROR("Encountered object in input, but the 'refuse_objects' option is in effect");
+#define SRL_ERROR_PANIC(dec, msg) SRL_ERRORf1("Panic: %s", msg);
 
 /* If set, the decoder struct needs to be cleared instead of freed at
  * the end of a deserialization operation */
